## V1.0.13 
- Completed all excel  comment
## V1.0.12
- Completed all excel input validation
## Webform
### V1.3.0 
- Done BCPNP 
### V1.2.0
- Added bcpnp 
### V1.1.0
- published on April 26, 2020. Based on new page model
### V1.0.1 
- create .prportalenv including rcics' account and password info in user's home directory

## Case

### V1.0.13
- pr: can generate 0008, 5406,5562,5669 excel sheets according to models
- lmia: added functions for generate excels for periods of assess, job post, and recruitment summary.
### V1.0.5
- bcpnp: generate company info, employer recommendation letter, employer training, employee training, job description, job offer form xml and rep form xml.
- exp: experience related doc auto generate: resume, employment certificate
- trv: read 5257,1294,1295,5708,5709,5710,and 5645
- recruit: generate job ad, job offer, and recruitment summary
- lmia: generate submission letter, employer training, employee training 
### V1.0.3 
- excel: add function. Now can add any number of excels instead of only 2. sub function is same 
- lmia: submission letter, employer training, employee traning for 5593 5626 5627 
- bcpnp: employer recommendation letter, company info, employer/employee training, job description auto doc makers
- job: job ad, job offer, employment certificate, resume for autodoc makers

## Model
### v1.0.16
- Added lmia assess stage data 
### V1.0.15 
- Added PR models for 0008 5669 5562 5406
